/*\file GetSolutionFromInputs.c
 *\brief: recover velocity ug from inputs
 */

#include "./GetSolutionFromInputs.h"

void mexFunction( int nlhs, mxArray* plhs[], int nrhs, const mxArray* prhs[]){

	/*diverse: */
	int   noerr=1;

	/*input datasets: */
	DataSet* elements=NULL;
	DataSet* nodes=NULL;
	DataSet* vertices=NULL;
	DataSet* loads=NULL;
	DataSet* materials=NULL;
	Parameters* parameters=NULL;
	int      analysis_type;
	int      sub_analysis_type;
	Vec      ug=NULL;

	/* output datasets: elements and loads*/

	/*Boot module: */
	MODULEBOOT();

	/*checks on arguments on the matlab side: */
	CheckNumMatlabArguments(nlhs,NLHS,nrhs,NRHS,__FUNCT__,&GetSolutionFromInputsUsage);
	
	/*Input datasets: */
	FetchData(&elements,ELEMENTSIN);
	FetchData(&nodes,NODES);
	FetchData(&vertices,VERTICES);
	FetchData(&loads,LOADSIN);
	FetchData(&materials,MATERIALS);
	FetchParams(&parameters,PARAMETERS);
	FetchData(&analysis_type,ANALYSISTYPE);
	FetchData(&sub_analysis_type,SUBANALYSISTYPE);

	/*!Configure objects:*/
	GetSolutionFromInputsx(&ug,elements, nodes,vertices,loads, materials,parameters,analysis_type,sub_analysis_type);

	/*write output datasets: */
	WriteData(UG,ug);

	/*Free ressources: */
	delete elements;
	delete nodes;
	delete vertices;
	delete loads;
	delete materials;
	delete parameters;

	/*end module: */
	MODULEEND();
}

void GetSolutionFromInputsUsage(void)
{
	_printf_("\n");
	_printf_("   usage: [ug] = %s(elements,nodes,vertices,loads, materials,parameters,analysis_type,sub_analysis_type);\n",__FUNCT__);
	_printf_("\n");
}
